@@ -25,7 +25,7 @@
 #include <glib-object.h>
 #include <atk/atkcomponent.h>
 #include <atk/atkstateset.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 
 #include "gtkhtml.h"
 #include "htmlengine.h"
@@ -43,8 +43,6 @@ static AtkStateSet * html_a11y_ref_state_set (AtkObject *accessible);
 static gint html_a11y_get_n_children (AtkObject *accessible);
 static AtkObject * html_a11y_ref_child (AtkObject *accessible, gint index);
 
-void html_a11y_get_size (AtkComponent *component, gint *width, gint *height);
-
 static AtkObjectClass *parent_class = NULL;
 
 GType
