@@ -123,10 +123,8 @@ static GList *
 point_get_parent_list (HTMLPoint *point, gint level, gboolean include_offset)
 {
 	GList *list;
-	HTMLObject *o;
 
 	list = include_offset ? g_list_prepend (NULL, GINT_TO_POINTER (point->offset)) : NULL;
-	o    = point->object;
 
 	object_get_parent_list (point->object, level, &list);
 
@@ -1214,10 +1212,14 @@ void
 html_engine_insert_empty_paragraph (HTMLEngine *e)
 {
 	HTMLClueFlow *cf;
+	HTMLClueFlowStyle cfs;
 
 	html_engine_freeze (e);
 	insert_empty_paragraph (e, HTML_UNDO_UNDO, TRUE);
 	cf = html_object_get_flow (e->cursor->object);
+	cfs = html_clueflow_get_style (cf);
+	if (cfs == HTML_CLUEFLOW_STYLE_H1 || cfs == HTML_CLUEFLOW_STYLE_H2 || cfs == HTML_CLUEFLOW_STYLE_H3 || cfs == HTML_CLUEFLOW_STYLE_H4 || cfs == HTML_CLUEFLOW_STYLE_H5 || cfs == HTML_CLUEFLOW_STYLE_H6)
+		html_clueflow_set_style (cf, e, HTML_CLUEFLOW_STYLE_NORMAL);
 	if (cf) {
 		cf->dir = html_text_direction_pango_to_html (gdk_keymap_get_direction (gdk_keymap_get_for_display (gtk_widget_get_display (GTK_WIDGET (e->widget)))));
 	}
@@ -1272,6 +1274,7 @@ use_pictograms (HTMLEngine *e)
 	if (state < 0) {
 		HTMLObject *picto;
 		gchar *filename;
+		gchar *filename_uri;
 		gchar *alt;
 		gint len;
 
@@ -1287,9 +1290,12 @@ use_pictograms (HTMLEngine *e)
 		html_engine_set_mark (e);
 		html_cursor_forward_n (e->cursor, e, len);
 
-		filename = g_strconcat ("file://" ICONDIR "/", picto_images [-state - 1], NULL);
-		picto = html_image_new (html_engine_get_image_factory (e), filename, NULL, NULL, -1, -1, FALSE, FALSE, 0, NULL,
+		filename = g_build_filename (ICONDIR, picto_images [-state - 1], NULL);
+		filename_uri = g_filename_to_uri (filename, NULL, NULL);
+		g_free (filename);
+		picto = html_image_new (html_engine_get_image_factory (e), filename_uri, NULL, NULL, -1, -1, FALSE, FALSE, 0, NULL,
 					HTML_VALIGN_MIDDLE, FALSE);
+		g_free (filename_uri);
 		html_image_set_alt (HTML_IMAGE (picto), alt);
 		html_object_set_data (HTML_OBJECT (picto), "picto", alt);
 		g_free (alt);
@@ -1490,9 +1496,6 @@ change_link (HTMLObject *o, HTMLEngine *e, gpointer data)
 	changed = d->url ? html_object_set_link (o, d->color, d->url, d->target) : html_object_remove_link (o, d->color);
 	if (changed) {
 		if (o->parent) {
-			HTMLObject *prev;
-
-			prev = o->prev;
 			g_assert (HTML_OBJECT_TYPE (o->parent) == HTML_TYPE_CLUEFLOW);
 
 			html_clue_append_after (HTML_CLUE (o->parent), changed, o);
@@ -1736,6 +1739,7 @@ check_for_simple_containers (HTMLObject *child, HTMLObject *parent)
 			case HTML_TYPE_CLUEFLOW:
 			case HTML_TYPE_CLUEV:
 			case HTML_TYPE_TABLECELL:
+			case HTML_TYPE_TABLE:
 				break;
 			default:
 				return FALSE;
